//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/Interface/LayerInterface.cpp
//! @brief     Implements class LayerInterface.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Sample/Interface/LayerInterface.h"
#include "Base/Util/Assert.h"
#include "Sample/Interface/LayerRoughness.h"

LayerInterface::LayerInterface(const Layer* top_layer, const Layer* bottom_layer,
                               const LayerRoughness* layerRoughness)
    : m_top_layer(top_layer)
    , m_bottom_layer(bottom_layer)
    , m_roughness(layerRoughness)
{
    ASSERT(top_layer);
    ASSERT(bottom_layer);
    ASSERT(layerRoughness);
}

LayerInterface::~LayerInterface() = default;

LayerInterface* LayerInterface::clone() const
{
    throw std::runtime_error("LayerInterface::clone -> Not allowed to clone.");
}

std::vector<const INode*> LayerInterface::nodeChildren() const
{
    return std::vector<const INode*>() << m_roughness;
}

std::string LayerInterface::validate() const
{
    return "";
}
